@@ -2,7 +2,7 @@
  *
  *  Connection Manager
  *
- *  Copyright (C) 2007-2009  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2007-2010  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -34,12 +34,14 @@ extern "C" {
 
 int connman_timeserver_append(const char *server);
 int connman_timeserver_remove(const char *server);
+void connman_timeserver_sync(void);
 
 struct connman_timeserver_driver {
 	const char *name;
 	int priority;
 	int (*append) (const char *server);
 	int (*remove) (const char *server);
+	void (*sync) (void);
 };
 
 int connman_timeserver_driver_register(struct connman_timeserver_driver *driver);
